==> connector-packaging-persnurse-3.18.0-net.zip: examples/be/ehealth/businessconnector/hubv3/helpers/HubConfigCommon.cs <==
﻿/*
 * Copyright (c) eHealth
 */
using System;
using be.fgov.ehealth.technicalconnector.tests.session;
using java.lang;
using java.util;
using be.ehealth.technicalconnector.idgenerator;
using be.ehealth.technicalconnector.utils;
using be.fgov.ehealth.hubservices.core.v3;
using NUnit.Framework;
using org.joda.time;
using be.ehealth.businessconnector.hubv3.builders;
using be.ehealth.businessconnector.hubv3.service;
using be.ehealth.businessconnector.hubv3.session;
using be.ehealth.businessconnector.hubv3.helpers;
using be.ehealth.technicalconnector.exception;
using be.fgov.ehealth.standards.kmehr.cd.v1;
using be.fgov.ehealth.standards.kmehr.id.v1;
using be.fgov.ehealth.standards.kmehr.schema.v1;
using be.ehealth.technicalconnector.config;
using be.ehealth.technicalconnector.config.impl;
using be.ehealth.technicalconnector.session;
using be.fgov.ehealth.technicalconnector.tests.utils;
using be.ehealth.business.intrahubcommons.exception;
using be.ehealth.business.kmehrcommons.helper;
using be.ehealth.businessconnector.testcommons;
using org.apache.commons.lang;

namespace be.ehealth.businessconnector.hubv3.helpers
{
    public class HubConfigCommon
    {
	    /*
         * Professional Information The nihii is found in the session
         */
        public static string PROF_NISS = "82051234978";
        public static string PROF_FIRSTNAME = "Hannes";
        public static string PROF_LASTNAME = "De Clercq";
        public static string PROF_PROFESSION = CDHCPARTYvalues.PERSPHYSICIAN.value();
    
        public static string HUB_NAME = "TEST HUB ORG";
    
        public static string MESSAGE_ID = "1";
	}
}

==> connector-packaging-persnurse-3.26.1-net.zip: examples/be/ehealth/businessconnector/hubv3/helpers/HubConfigCommon.cs <==
﻿﻿/*
 * Copyright (c) eHealth
 */
using System;
using be.fgov.ehealth.technicalconnector.tests.session;
using java.lang;
using java.util;
using be.ehealth.technicalconnector.idgenerator;
using be.ehealth.technicalconnector.utils;
using be.fgov.ehealth.hubservices.core.v3;
using NUnit.Framework;
using org.joda.time;
using be.ehealth.businessconnector.hubv3.builders;
using be.ehealth.businessconnector.hubv3.service;
using be.ehealth.businessconnector.hubv3.session;
using be.ehealth.businessconnector.hubv3.helpers;
using be.ehealth.technicalconnector.exception;
using be.fgov.ehealth.standards.kmehr.cd.v1;
using be.fgov.ehealth.standards.kmehr.id.v1;
using be.fgov.ehealth.standards.kmehr.schema.v1;
using be.ehealth.technicalconnector.config;
using be.ehealth.technicalconnector.config.impl;
using be.ehealth.technicalconnector.session;
using be.fgov.ehealth.businessconnector.tests.utils;
using be.fgov.ehealth.technicalconnector.tests.utils;
using be.ehealth.business.intrahubcommons.exception;
using be.ehealth.business.test.kmehrcommons.helper;
using be.ehealth.businessconnector.test.testcommons;
using org.apache.commons.lang;

namespace be.ehealth.businessconnector.hubv3.helpers
{
    public class HubConfigCommon
    {
	    /*
         * Professional Information The nihii is found in the session
         */
        public static string PROF_NISS = "82051234978";
        public static string PROF_FIRSTNAME = "Hannes";
        public static string PROF_LASTNAME = "De Clercq";
        public static string PROF_PROFESSION = CDHCPARTYvalues.PERSPHYSICIAN.value();
    
        public static string HUB_NAME = "TEST HUB ORG";
    
        public static string MESSAGE_ID = "1";
	}
}
